@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use base qw(Catalyst::Controller::CRUD);
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 =head1 NAME
 
@@ -15,7 +15,7 @@ Catalyst::Controller::CRUD::CDBI - CRUD (create/read/update/delete) Controller f
   # MyApp/lib/MyApp.pm
   package MyApp;
   
-  use Catalyst qw/-Debug MakeText CRUD::CDBI/;
+  use Catalyst qw/-Debug I18N CRUD Static::Simple/;
   
   1;
   
@@ -159,7 +159,7 @@ sub get_models {
 
 =head1 SEE ALSO
 
-Catalyst::Controller::CRUD, Class::DBI, DBIx::Class
+Catalyst::Controller::CRUD, Class::DBI
 
 =head1 AUTHOR
 
